Learn R Programming

monochromeR (version 0.2.0)

view_palette: Easy way to view the created palette

Description

Easy way to view the created palette

Usage

view_palette(monochrome_palette, view_labels = TRUE)

Value

A plot showing all the colours in the palette on the same row

Arguments

monochrome_palette

Vector of hex colour codes, or a generate_palette() call

view_labels

Logical. If view_palette is set to TRUE, view_labels determines whether or not the hex colour codes are shown on the palette displayed in the plot window.

Examples

Run this code
view_palette(c("#464E69", "#8C90A1", "#D1D2D9"))
view_palette(c("unripe" = "#89973d", "ripe" = "#e8b92f", "overripe" = "#a45e41"))
view_palette(generate_palette("pink", "go_darker", n_colours = 3))

Run the code above in your browser using DataLab